@@ -12,7 +12,7 @@ void CGI::setQuery()
         case POST:
             if (d_boundary.length() == 0)
             {
-                unique_ptr<char> cp(new char[d_contentLength]);
+                unique_ptr<char[]> cp(new char[d_contentLength]);
             
                 if (!cin.read(cp.get(), d_contentLength))
                     d_status = "invalid CONTENT_LENGTH in POSTed form";
